@rem
@rem Copyright 2015 the original author or authors.
@rem
@rem Licensed under the Apache License, Version 2.0 (the "License");
@rem you may not use this file except in compliance with the License.
@rem You may obtain a copy of the License at
@rem
@rem      https://www.apache.org/licenses/LICENSE-2.0
@rem
@rem Unless required by applicable law or agreed to in writing, software
@rem distributed under the License is distributed on an "AS IS" BASIS,
@rem WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@rem See the License for the specific language governing permissions and
@rem limitations under the License.
@rem
@rem SPDX-License-Identifier: Apache-2.0
@rem

@if "%DEBUG%"=="" @echo off
@rem ##########################################################################
@rem
@rem  pdf-as-cli startup script for Windows
@rem
@rem ##########################################################################

@rem Set local scope for the variables with windows NT shell
if "%OS%"=="Windows_NT" setlocal

set DIRNAME=%~dp0
if "%DIRNAME%"=="" set DIRNAME=.
@rem This is normally unused
set APP_BASE_NAME=%~n0
set APP_HOME=%DIRNAME%..

@rem Resolve any "." and ".." in APP_HOME to make it shorter.
for %%i in ("%APP_HOME%") do set APP_HOME=%%~fi

@rem Add default JVM options here. You can also use JAVA_OPTS and PDF_AS_CLI_OPTS to pass JVM options to this script.
set DEFAULT_JVM_OPTS=

@rem Find java.exe
if defined JAVA_HOME goto findJavaFromJavaHome

set JAVA_EXE=java.exe
%JAVA_EXE% -version >NUL 2>&1
if %ERRORLEVEL% equ 0 goto execute

echo. 1>&2
echo ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH. 1>&2
echo. 1>&2
echo Please set the JAVA_HOME variable in your environment to match the 1>&2
echo location of your Java installation. 1>&2

goto fail

:findJavaFromJavaHome
set JAVA_HOME=%JAVA_HOME:"=%
set JAVA_EXE=%JAVA_HOME%/bin/java.exe

if exist "%JAVA_EXE%" goto execute

echo. 1>&2
echo ERROR: JAVA_HOME is set to an invalid directory: %JAVA_HOME% 1>&2
echo. 1>&2
echo Please set the JAVA_HOME variable in your environment to match the 1>&2
echo location of your Java installation. 1>&2

goto fail

:execute
@rem Setup the command line

set CLASSPATH=%APP_HOME%\lib\pdf-as-cli-5.0.0.jar;%APP_HOME%\lib\sigs-pkcs7detached-5.0.0.jar;%APP_HOME%\lib\sigs-pades-5.0.0.jar;%APP_HOME%\lib\pdf-as-moa-5.0.0.jar;%APP_HOME%\lib\pdf-as-pdfbox-3-5.0.0.jar;%APP_HOME%\lib\pdf-as-lib-5.0.0.jar;%APP_HOME%\lib\iaik_eccelerate_cms-6.02.jar;%APP_HOME%\lib\iaik_eccelerate-6.02.jar;%APP_HOME%\lib\iaik_jce_full-5.63_moa.jar;%APP_HOME%\lib\iaik_cms-5.1.1.jar;%APP_HOME%\lib\pdf-as-common-5.0.0.jar;%APP_HOME%\lib\lombok-1.18.46.jar;%APP_HOME%\lib\commons-collections4-4.5.0.jar;%APP_HOME%\lib\commons-cli-1.11.0.jar;%APP_HOME%\lib\jaxb-runtime-4.0.7.jar;%APP_HOME%\lib\jaxb-core-4.0.7.jar;%APP_HOME%\lib\jakarta.xml.ws-api-4.0.3.jar;%APP_HOME%\lib\jakarta.xml.bind-api-4.0.5.jar;%APP_HOME%\lib\jakarta.xml.soap-api-3.0.2.jar;%APP_HOME%\lib\angus-activation-2.0.3.jar;%APP_HOME%\lib\jakarta.activation-api-2.1.4.jar;%APP_HOME%\lib\logback-classic-1.5.32.jar;%APP_HOME%\lib\kotlin-stdlib-2.2.21.jar;%APP_HOME%\lib\micrometer-core-1.16.5.jar;%APP_HOME%\lib\micrometer-observation-1.16.5.jar;%APP_HOME%\lib\micrometer-commons-1.16.5.jar;%APP_HOME%\lib\httpmime-4.5.14.jar;%APP_HOME%\lib\httpclient-4.5.14.jar;%APP_HOME%\lib\commons-codec-1.21.0.jar;%APP_HOME%\lib\commons-text-1.14.0.jar;%APP_HOME%\lib\commons-lang3-3.20.0.jar;%APP_HOME%\lib\preflight-3.0.6.jar;%APP_HOME%\lib\pdfbox-tools-3.0.6.jar;%APP_HOME%\lib\pdfbox-debugger-3.0.6.jar;%APP_HOME%\lib\pdfbox-3.0.6.jar;%APP_HOME%\lib\xmpbox-3.0.6.jar;%APP_HOME%\lib\fontbox-3.0.6.jar;%APP_HOME%\lib\pdfbox-io-3.0.6.jar;%APP_HOME%\lib\commons-logging-1.3.6.jar;%APP_HOME%\lib\txw2-4.0.7.jar;%APP_HOME%\lib\gson-2.13.2.jar;%APP_HOME%\lib\httpcore-4.4.16.jar;%APP_HOME%\lib\jspecify-1.0.0.jar;%APP_HOME%\lib\logback-core-1.5.32.jar;%APP_HOME%\lib\jcl-over-slf4j-2.0.17.jar;%APP_HOME%\lib\jose4j-0.9.6.jar;%APP_HOME%\lib\slf4j-api-2.0.17.jar;%APP_HOME%\lib\bcpkix-jdk18on-1.82.jar;%APP_HOME%\lib\bcutil-jdk18on-1.82.jar;%APP_HOME%\lib\bcprov-jdk18on-1.82.jar;%APP_HOME%\lib\commons-io-2.21.0.jar;%APP_HOME%\lib\ognl-3.3.5.jar;%APP_HOME%\lib\javase-3.5.0.jar;%APP_HOME%\lib\core-3.5.0.jar;%APP_HOME%\lib\jakarta.jws-api-3.0.0.jar;%APP_HOME%\lib\jbig2-imageio-3.0.5.jar;%APP_HOME%\lib\javassist-3.29.0-GA.jar;%APP_HOME%\lib\jcommander-1.82.jar;%APP_HOME%\lib\jai-imageio-core-1.4.0.jar;%APP_HOME%\lib\error_prone_annotations-2.41.0.jar;%APP_HOME%\lib\HdrHistogram-2.2.2.jar;%APP_HOME%\lib\LatencyUtils-2.0.3.jar;%APP_HOME%\lib\picocli-4.7.7.jar;%APP_HOME%\lib\annotations-13.0.jar;%APP_HOME%\lib\istack-commons-runtime-4.1.2.jar


@rem Execute pdf-as-cli
"%JAVA_EXE%" %DEFAULT_JVM_OPTS% %JAVA_OPTS% %PDF_AS_CLI_OPTS%  -classpath "%CLASSPATH%" at.gv.egiz.pdfas.cli.Main %*

:end
@rem End local scope for the variables with windows NT shell
if %ERRORLEVEL% equ 0 goto mainEnd

:fail
rem Set variable PDF_AS_CLI_EXIT_CONSOLE if you need the _script_ return code instead of
rem the _cmd.exe /c_ return code!
set EXIT_CODE=%ERRORLEVEL%
if %EXIT_CODE% equ 0 set EXIT_CODE=1
if not ""=="%PDF_AS_CLI_EXIT_CONSOLE%" exit %EXIT_CODE%
exit /b %EXIT_CODE%

:mainEnd
if "%OS%"=="Windows_NT" endlocal

:omega
